Method: Cinch::Timer#threaded

Defined in:
lib/cinch/timer.rb

#threadedBoolean Also known as: threaded?

Returns If true, each invocation will be executed in a thread of its own.

Returns:

  • (Boolean)

    If true, each invocation will be executed in a thread of its own.

Since:

  • 2.0.0



32
33
34
# File 'lib/cinch/timer.rb', line 32

def threaded
  @threaded
end